# Change Log

## v0.1.6 - 2024-08-17

- Bump libisg to v0.2.5

## v0.1.5 - 2024-08-06

- Fix `dump(s)` 3 columns data

## v0.1.4 - 2024-08-03

- Enable LTO
- Fix error message of `comment` type error on `dump(s)`

## v0.1.3 - 2024-07-29

- Fix serializing `lat_max`, `lon_min` and `lon_max`
- Fix to relax `dump` and `dumps` args type

## v0.1.2 - 2024-07-27

Fix error handling on not supported platform

## v0.1.1 - 2024-07-27

Fix types of `Header`

## v0.1.0 - 2024-07-27

First release
